pub enum ConfigurationLoadError {
    NotFound {
        loader: String,
        url: Url,
    },
    NoAccess {
        loader: String,
        url: Url,
    },
    Timeout {
        loader: String,
        url: Url,
        timeout_in_seconds: usize,
    },
    InvalidUrl {
        loader: String,
        url: String,
        source: Error,
    },
    UrlSchemeNotFound {
        scheme: String,
    },
    Duplicate {
        loader: String,
        url: Url,
        plugin: String,
        format_1: String,
        format_2: String,
    },
    Load {
        loader: String,
        url: Url,
        description: String,
        source: Error,
        skippable: bool,
    },
    AcquireLock {
        url: Url,
    },
    Other(Error),
}
Loaded error type.

Variants



NotFound

Fields

loader: String
url: Url

An entity could not be found.



NoAccess

Fields

loader: String
url: Url

Did not have enough permissions to read the contents.



Timeout

Fields

loader: String
url: Url
timeout_in_seconds: usize

Got timeout when reading the contents.



InvalidUrl

Fields

loader: String
source: Error

The provided URL is invalid.



UrlSchemeNotFound

Fields

scheme: String

Could not found URL scheme.



Duplicate

Fields

loader: String
url: Url
plugin: String
format_1: String
format_2: String

Found more than one configuration with two different formats (extensions) for the same plugin.



Load

Fields

loader: String
url: Url
description: String
source: Error
skippable: bool

Could not load the configuration.

note that skippable key is very important. You might want to detect your own options from provided Url and sometimes make some errors skippable based on you detected options.



AcquireLock

Fields

url: Url


Other(Error)

Implementations