pub fn deserialize_query_string<T: DeserializeOwned>(
    loader_name: &'static str,
    url: &Url
) -> Result<T, ConfigurationLoadError>
Checks query-string part of URL and tries to deserialize it to provided type.

See supported syntax at serde_qs. This function is only usable if qs Cargo feature is enabled.