Loader

Trait Loader 

pub trait Loader:
    Send
    + Sync
    + Debug
    + Display {
    // Required methods
    fn scheme_list(&self) -> Vec<String>;
    fn load(
        &self,
        url: &Url,
        maybe_whitelist: Option<&[String]>,
        skip_soft_errors: bool,
    ) -> Result<Vec<(String, ConfigurationEntity)>, Error>;
}
A trait to load configurations for one or more plugins.

Required Methods

fn scheme_list(&self) -> Vec<String>

List of URL schemes that this loader supports.

Different URL may be assigned to this loader by their scheme value.

fn load( &self, url: &Url, maybe_whitelist: Option<&[String]>, skip_soft_errors: bool, ) -> Result<Vec<(String, ConfigurationEntity)>, Error>

Main method that actually loads configurations.

  • Checks the url and detects its own options from it.
  • Checks whitelist to load just provided plugins configurations.
  • Attempts to load configurations.
  • Tries to set format for each ConfigurationEntity.

Implementors