pub struct ConfigurationEntity { /* private fields */ }
A configuration entity for each plugin.

Implementations

source

impl ConfigurationEntity

source

pub fn new<P, L>(url: Url, plugin_name: P, loader_name: L) -> Selfwhere P: AsRef<str>, L: AsRef<str>,

Constructs a new ConfigurationEntity.

It’s better to set the format (via Self::set_format or Self::with_format) and if we don’t and try to parse its contents, All parsers that support ConfigurationParser::is_format_supported method try to validate the contents to pick it up for future parsing!

source

pub fn set_format<F: AsRef<str>>(&mut self, format: F)

source

pub fn with_format<F: AsRef<str>>(self, format: F) -> Self

source

pub fn set_contents<C: AsRef<str>>(&mut self, contents: C)

source

pub fn with_contents<C: AsRef<str>>(self, contents: C) -> Self

source

pub fn set_parsed_contents<I: Into<Input>>(&mut self, contents: I)

source

pub fn with_parsed_contents<I: Into<Input>>(self, contents: I) -> Self

source

pub fn url(&self) -> &Url

source

pub fn url_mut(&mut self) -> &mut Url

source

pub fn plugin_name(&self) -> &String

source

pub fn plugin_name_mut(&mut self) -> &mut String

source

pub fn maybe_format(&self) -> Option<&String>

source

pub fn maybe_format_mut(&mut self) -> &mut Option<String>

source

pub fn maybe_contents(&self) -> Option<&String>

source

pub fn maybe_contents_mut(&mut self) -> &mut Option<String>

source

pub fn maybe_parsed_contents(&self) -> Option<&Input>

source

pub fn maybe_parsed_contents_mut(&mut self) -> &mut Option<Input>

source

pub fn guess_format( &self, parser_list: &[Box<dyn ConfigurationParser>] ) -> Option<String>

We have to call it after calling Self::set_contents or Self::with_contents and If no contents is set, It yields None too.

source

pub fn parse_contents( &self, parser_list: &[Box<dyn ConfigurationParser>] ) -> Result<Input, ConfigurationParserError>

source

pub fn parse_contents_mut( &mut self, parser_list: &[Box<dyn ConfigurationParser>] ) -> Result<&mut Input, ConfigurationParserError>