pub enum ConfigurationLoadError {
NotFound {
loader: String,
url: String,
},
NoAccess {
loader: String,
url: String,
},
Timeout {
loader: String,
url: String,
timeout_in_seconds: usize,
},
InvalidUrl {
loader: String,
url: String,
error: Error,
},
UrlSchemeNotFound {
scheme: String,
},
Duplicate {
loader: String,
url: String,
plugin: String,
format_1: String,
format_2: String,
},
Load {
loader: String,
url: String,
description: String,
source: Error,
skippable: bool,
},
AcquireLock {
url: String,
},
Other(Error),
}Expand description
Loaded error type.
Variants
NotFound
An entity could not be found.
NoAccess
Did not have enough permissions to read the contents.
Timeout
Got timeout when reading the contents.
InvalidUrl
The provided URL is invalid.
UrlSchemeNotFound
Could not found URL scheme.
Duplicate
Found more than one configuration with two different formats (extensions) for the same plugin.
Load
Could not load the configuration.
note that skippable key is very important. You might want to detect your own options from
provided Url and sometimes make some errors skippable based on you detected options.
AcquireLock
Other(Error)
Implementations
sourceimpl ConfigurationLoadError
impl ConfigurationLoadError
pub fn is_skippable(&self) -> bool